@@ -63,6 +63,7 @@ func (b *Block) setActiveSegment(segment *Segment) {
 	b.activeSegment = segment
 	b.activeBackground = segment.background()
 	b.activeForeground = segment.foreground()
+	b.writer.setColors(b.activeBackground, b.activeForeground)
 }
 
 func (b *Block) enabled() bool {
@@ -95,87 +96,28 @@ func (b *Block) renderSegments() string {
 		if !segment.active {
 			continue
 		}
-		b.setActiveSegment(segment)
-		b.writer.setColors(b.activeBackground, b.activeForeground)
-		b.endPowerline()
-		b.renderSegmentText(segment.stringValue)
-	}
-	if b.previousActiveSegment != nil && b.previousActiveSegment.Style == Powerline {
-		b.writePowerLineSeparator(Transparent, b.previousActiveSegment.background(), true)
+		b.renderSegment(segment)
 	}
+	b.writePowerline(true)
 	b.writer.clearParentColors()
 	return b.writer.string()
 }
 
-func (b *Block) endPowerline() {
-	if b.previousActiveSegment == nil || b.activeSegment == nil {
-		return
-	}
-	if b.activeSegment.Style != Powerline &&
-		b.previousActiveSegment.Style == Powerline {
-		b.writePowerLineSeparator(b.getPowerlineColor(false), b.previousActiveSegment.background(), true)
-	}
-}
-
-func (b *Block) writePowerLineSeparator(background, foreground string, end bool) {
-	symbol := b.activeSegment.PowerlineSymbol
-	if end {
-		symbol = b.previousActiveSegment.PowerlineSymbol
-	}
-	if b.activeSegment.InvertPowerline {
-		b.writer.write(foreground, background, symbol)
-		return
-	}
-	b.writer.write(background, foreground, symbol)
-}
-
-func (b *Block) getPowerlineColor(foreground bool) string {
-	if b.previousActiveSegment == nil {
-		return Transparent
-	}
-	if b.previousActiveSegment.Style == Diamond && len(b.previousActiveSegment.TrailingDiamond) == 0 {
-		return b.previousActiveSegment.background()
-	}
-	if b.activeSegment.Style == Diamond && len(b.activeSegment.LeadingDiamond) == 0 {
-		return b.activeBackground
-	}
-	if !foreground && b.activeSegment.Style != Powerline {
-		return Transparent
-	}
-	if foreground && b.previousActiveSegment.Style != Powerline {
-		return Transparent
-	}
-	return b.previousActiveSegment.background()
-}
-
-func (b *Block) renderSegmentText(text string) {
+func (b *Block) renderSegment(segment *Segment) {
+	b.setActiveSegment(segment)
+	b.writePowerline(false)
 	switch b.activeSegment.Style {
-	case Plain:
-		b.renderPlainSegment(text)
+	case Plain, Powerline:
+		b.renderText(segment.stringValue)
 	case Diamond:
-		b.renderDiamondSegment(text)
-	case Powerline:
-		b.renderPowerLineSegment(text)
+		b.writer.write(Transparent, b.activeBackground, b.activeSegment.LeadingDiamond)
+		b.renderText(segment.stringValue)
+		b.writer.write(Transparent, b.activeBackground, b.activeSegment.TrailingDiamond)
 	}
 	b.previousActiveSegment = b.activeSegment
 	b.writer.setParentColors(b.activeBackground, b.activeForeground)
 }
 
-func (b *Block) renderPowerLineSegment(text string) {
-	b.writePowerLineSeparator(b.activeBackground, b.getPowerlineColor(true), false)
-	b.renderText(text)
-}
-
-func (b *Block) renderPlainSegment(text string) {
-	b.renderText(text)
-}
-
-func (b *Block) renderDiamondSegment(text string) {
-	b.writer.write(Transparent, b.activeBackground, b.activeSegment.LeadingDiamond)
-	b.renderText(text)
-	b.writer.write(Transparent, b.activeBackground, b.activeSegment.TrailingDiamond)
-}
-
 func (b *Block) renderText(text string) {
 	defaultValue := " "
 	b.writer.write(b.activeBackground, b.activeForeground, b.activeSegment.getValue(Prefix, defaultValue))
@@ -183,6 +125,50 @@ func (b *Block) renderText(text string) {
 	b.writer.write(b.activeBackground, b.activeForeground, b.activeSegment.getValue(Postfix, defaultValue))
 }
 
+func (b *Block) writePowerline(final bool) {
+	resolvePowerlineSymbol := func() string {
+		var symbol string
+		if b.activeSegment.Style == Powerline {
+			symbol = b.activeSegment.PowerlineSymbol
+		} else if b.previousActiveSegment != nil && b.previousActiveSegment.Style == Powerline {
+			symbol = b.previousActiveSegment.PowerlineSymbol
+		}
+		return symbol
+	}
+	symbol := resolvePowerlineSymbol()
+	if len(symbol) == 0 {
+		return
+	}
+	background := b.activeSegment.background()
+	if final || b.activeSegment.Style != Powerline {
+		background = Transparent
+	}
+	if b.activeSegment.Style == Diamond && len(b.activeSegment.LeadingDiamond) == 0 {
+		background = b.activeSegment.background()
+	}
+	if b.activeSegment.InvertPowerline {
+		b.writer.write(b.getPowerlineColor(), background, symbol)
+		return
+	}
+	b.writer.write(background, b.getPowerlineColor(), symbol)
+}
+
+func (b *Block) getPowerlineColor() string {
+	if b.previousActiveSegment == nil {
+		return Transparent
+	}
+	if b.previousActiveSegment.Style == Diamond && len(b.previousActiveSegment.TrailingDiamond) == 0 {
+		return b.previousActiveSegment.background()
+	}
+	if b.activeSegment.Style == Diamond && len(b.activeSegment.LeadingDiamond) == 0 {
+		return b.previousActiveSegment.background()
+	}
+	if b.previousActiveSegment.Style != Powerline {
+		return Transparent
+	}
+	return b.previousActiveSegment.background()
+}
+
 func (b *Block) debug() (int, []*SegmentTiming) {
 	var segmentTimings []*SegmentTiming
 	largestSegmentNameLength := 0
@@ -204,14 +190,10 @@ func (b *Block) debug() (int, []*SegmentTiming) {
 		// string() timing
 		if segmentTiming.enabled {
 			start = time.Now()
-			segmentTiming.stringValue = segment.string()
+			segment.stringValue = segment.string()
 			segmentTiming.stringDuration = time.Since(start)
-			b.previousActiveSegment = nil
-			b.setActiveSegment(segment)
-			b.renderSegmentText(segmentTiming.stringValue)
-			if b.activeSegment.Style == Powerline {
-				b.writePowerLineSeparator(Transparent, b.activeBackground, true)
-			}
+			b.renderSegment(segment)
+			b.writePowerline(true)
 			segmentTiming.stringValue = b.writer.string()
 			b.writer.reset()
 		}
