@@ -1,7 +1,7 @@
 package main
 
 type dotnet struct {
-	language *language
+	language
 }
 
 const (
@@ -22,7 +22,7 @@ func (d *dotnet) string() string {
 }
 
 func (d *dotnet) init(props properties, env environmentInfo) {
-	d.language = &language{
+	d.language = language{
 		env:        env,
 		props:      props,
 		extensions: []string{"*.cs", "*.csx", "*.vb", "*.sln", "*.csproj", "*.vbproj", "*.fs", "*.fsx", "*.fsproj", "global.json"},
