@@ -1,7 +1,7 @@
 package main
 
 type php struct {
-	language *language
+	language
 }
 
 func (n *php) string() string {
@@ -9,7 +9,7 @@ func (n *php) string() string {
 }
 
 func (n *php) init(props properties, env environmentInfo) {
-	n.language = &language{
+	n.language = language{
 		env:        env,
 		props:      props,
 		extensions: []string{"*.php", "composer.json", "composer.lock", ".php-version"},
